@@ -259,12 +259,18 @@ class Project:  # pylint: disable=too-many-instance-attributes
         models_init_template = self.env.get_template("models_init.py.jinja")
         models_init.write_text(models_init_template.render(imports=imports, alls=alls), encoding=self.file_encoding)
 
+    # pylint: disable=too-many-locals
     def _build_api(self) -> None:
         # Generate Client
         client_path = self.package_dir / "client.py"
         client_template = self.env.get_template("client.py.jinja")
         client_path.write_text(client_template.render(), encoding=self.file_encoding)
 
+        # Generate included Errors
+        errors_path = self.package_dir / "errors.py"
+        errors_template = self.env.get_template("errors.py.jinja")
+        errors_path.write_text(errors_template.render(), encoding=self.file_encoding)
+
         # Generate endpoints
         api_dir = self.package_dir / "api"
         api_dir.mkdir()
